[![Travis Status](https://secure.travis-ci.org/mbraak/jqTree.png)](http://travis-ci.org/mbraak/jqTree) [![Coverage Status](https://coveralls.io/repos/mbraak/jqTree/badge.png?branch=dev)](https://coveralls.io/r/mbraak/jqTree?branch=dev) [![Bower version](https://badge.fury.io/bo/jqtree.png)](http://badge.fury.io/bo/jqtree)

#jqTree

JqTree is a tree widget. Read more in the [documentation](http://mbraak.github.io/jqTree/).

![screenshot](https://raw.github.com/mbraak/jqTree/master/screenshot.png)

##Features

* Create a tree from JSON data
* Drag and drop
* Works on ie7+, firefox 3.6+, chrome and safari
* Written in Coffeescript

The project is hosted on [github](https://github.com/mbraak/jqTree), has a [test suite](http://mbraak.github.io/jqTree/test/test.html).

See index.html for the full documentation. The documentation is also on [github](http://mbraak.github.io/jqTree/)

##Thanks

The code for the mouse widget is heavily inspired by the mouse widget from jquery ui.
Tree graphic designed by Hernan D. Schlosman from The Noun Project.


[![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/mbraak/jqtree/trend.png)](https://bitdeli.com/free "Bitdeli Badge")

